@@ -3,9 +3,13 @@ from __future__ import unicode_literals
 
 import collections
 
+from identify import identify
+
 from git_code_debt.metric import Metric
 from git_code_debt.metrics.base import DiffParserBase
-from git_code_debt.metrics.common import FILE_TYPE_MAP
+from git_code_debt.metrics.base import MetricInfo
+from git_code_debt.metrics.common import ALL_TAGS
+from git_code_debt.metrics.common import UNKNOWN
 from git_code_debt.metrics.curse_words import word_list
 
 
@@ -34,20 +38,19 @@ class CurseWordsParser(DiffParserBase):
             total_curses = total_curses + curses_changed
 
             # Track by file extension -> type mapping
-            file_type = FILE_TYPE_MAP.get(file_diff_stat.extension, 'unknown')
-            curses_by_file_type[file_type] += curses_changed
+            filename = file_diff_stat.filename.decode('UTF-8')
+            tags = identify.tags_from_filename(filename) or {UNKNOWN}
+
+            for tag in tags:
+                curses_by_file_type[tag] += curses_changed
 
         # Yield overall metric and one per type of expected mapping types
         yield Metric('TotalCurseWords', total_curses)
-        for file_type in set(FILE_TYPE_MAP.values()) | {'unknown'}:
-            curses_changed = curses_by_file_type.get(file_type, 0)
-            yield Metric(
-                'TotalCurseWords_{}'.format(file_type),
-                curses_changed,
-            )
+        for tag, value in curses_by_file_type.items():
+            if tag in ALL_TAGS and value:
+                yield Metric('TotalCurseWords_{}'.format(tag), value)
 
-    def get_possible_metric_ids(self):
-        return ['TotalCurseWords'] + [
-            'TotalCurseWords_{}'.format(file_type)
-            for file_type in set(FILE_TYPE_MAP.values()) | {'unknown'}
-        ]
+    def get_metrics_info(self):
+        metric_names = ['TotalCurseWords_{}'.format(tag) for tag in ALL_TAGS]
+        metric_names.append('TotalCurseWords')
+        return [MetricInfo(metric_name) for metric_name in metric_names]
